==> zim-fuzzysearch-0.7.1.tgz: package/lib/components/index.js <==
import React from "react";
import { useFuse } from "./hooks/useFuse";
import { FuzzyInputProvider } from "./hooks/useFuzzyInput";
import { FuzzyResultProvider } from "./hooks/useFuzzyResult";
import FuzzyGui from "./FuzzyGui";
// fuse specific default option
var optionsDefault = {
    //includeMatches: true,
    ignoreLocation: true,
    ignoreFieldNorm: false,
    includeScore: true,
    keys: ["label", "txt", "tags"]
};
//default options for mark.js
var markOptionsDefault = {
    element: "b",
    accuracy: "complementary",
    exclude: ["h5"],
};
var ZIMFuzzySearch = function (_a) {
    var data = _a.data, tagConceptMap = _a.tagConceptMap, onSelect = _a.onSelect, onSearch = _a.onSearch, searchInput = _a.searchInput, _b = _a.placeHolder, placeHolder = _b === void 0 ? "Search..." : _b, onInput = _a.onInput, _c = _a.fuseOptions, fuseOptions = _c === void 0 ? optionsDefault : _c, _d = _a.markOptions, markOptions = _d === void 0 ? markOptionsDefault : _d, _e = _a.resultCountLabel, resultCountLabel = _e === void 0 ? "Matches: " : _e, _f = _a.searchOnClick, searchOnClick = _f === void 0 ? false : _f, _g = _a.fuseKeyMap, fuseKeyMap = _g === void 0 ? null : _g, children = _a.children;
    var _h = React.useState(fuseOptions), fuseStateOptions = _h[0], setFuseStateOptions = _h[1];
    var _j = React.useState(searchInput ? searchInput : null), inputVal = _j[0], setInputVal = _j[1];
    var fuseSearchInputDelay = React.useRef(undefined);
    var _k = useFuse(fuseStateOptions, data), fuseResult = _k.fuseResult, doFuseSearch = _k.doFuseSearch, groupBy = _k.groupBy, resetFuse = _k.resetFuse;
    // two way binding
    React.useEffect(function () {
        if (!searchInput)
            return;
        setInputVal(searchInput);
    }, [searchInput, data]);
    // when value set from outside -> do a fuse serach once
    React.useEffect(function () {
        if (!searchInput)
            return;
        // when value set from outside -> trigger search once.
        if (searchOnClick && !fuseResult && data) {
            doFuseSearch(searchInput);
            if (onSearch)
                onSearch(searchInput);
        }
    }, [data]);
    // when input change do search when not in clickmode.
    // timer delays init auf fusesearch(e.g. if multiple inputs)
    React.useEffect(function () {
        if (fuseSearchInputDelay.current)
            clearTimeout(fuseSearchInputDelay.current);
        if (!searchOnClick && inputVal) {
            fuseSearchInputDelay.current = setTimeout(function () {
                if (fuseSearchInputDelay.current) {
                    doFuseSearch(inputVal);
                    if (onSearch)
                        onSearch(inputVal);
                }
            }, 300);
        }
        else if (inputVal === null) {
            resetFuse();
        }
    }, [searchInput, data, inputVal]);
    var handleInput = function (val) {
        setInputVal(val);
        // ensure two way binding
        if (onInput)
            onInput(val ? val : "");
    };
    var toggleFuseKey = function (fuseKeys) {
        var copy = JSON.parse(JSON.stringify(fuseSearchInputDelay));
        copy.keys = fuseKeys;
        setFuseStateOptions(copy);
    };
    /**
     * Trigger fuse search whenever fuse options change.
     */
    React.useEffect(function () {
        //do only fire 
        if (fuseOptions === fuseStateOptions)
            return;
        if (!inputVal)
            return;
        doFuseSearch(inputVal);
    }, [fuseStateOptions]);
    return (React.createElement(FuzzyInputProvider, { fuseStateOptions: fuseStateOptions, fuseKeyMap: fuseKeyMap, toggleFuseKey: toggleFuseKey, clickMode: searchOnClick, doSearch: doFuseSearch, onSearch: onSearch, handleInput: handleInput, inputVal: inputVal, placeHolder: placeHolder, data: data },
        React.createElement(FuzzyResultProvider, { fuzzyResult: fuseResult, onSelect: onSelect, resultCountLabel: resultCountLabel, tagConceptMap: tagConceptMap }, children ? children : React.createElement(FuzzyGui, { markOptions: markOptions }))));
};
export default ZIMFuzzySearch;

==> zim-fuzzysearch-0.7.2.tgz: package/lib/components/index.js <==
import React from "react";
import { useFuse } from "./hooks/useFuse";
import { FuzzyInputProvider } from "./hooks/useFuzzyInput";
import { FuzzyResultProvider } from "./hooks/useFuzzyResult";
import FuzzyGui from "./FuzzyGui";
// fuse specific default option
var optionsDefault = {
    //includeMatches: true,
    ignoreLocation: true,
    ignoreFieldNorm: false,
    includeScore: true,
    keys: ["label", "txt", "tags"]
};
//default options for mark.js
var markOptionsDefault = {
    element: "b",
    accuracy: "complementary",
    exclude: ["h5"],
};
var ZIMFuzzySearch = function (_a) {
    var data = _a.data, tagConceptMap = _a.tagConceptMap, onSelect = _a.onSelect, onSearch = _a.onSearch, searchInput = _a.searchInput, _b = _a.placeHolder, placeHolder = _b === void 0 ? "Search..." : _b, onInput = _a.onInput, _c = _a.fuseOptions, fuseOptions = _c === void 0 ? optionsDefault : _c, _d = _a.markOptions, markOptions = _d === void 0 ? markOptionsDefault : _d, _e = _a.resultCountLabel, resultCountLabel = _e === void 0 ? "Matches: " : _e, _f = _a.searchOnClick, searchOnClick = _f === void 0 ? false : _f, _g = _a.showResultGrid, showResultGrid = _g === void 0 ? false : _g, _h = _a.fuseKeyMap, fuseKeyMap = _h === void 0 ? null : _h, children = _a.children;
    var _j = React.useState(fuseOptions), fuseStateOptions = _j[0], setFuseStateOptions = _j[1];
    var _k = React.useState(searchInput ? searchInput : null), inputVal = _k[0], setInputVal = _k[1];
    var fuseSearchInputDelay = React.useRef(undefined);
    var _l = useFuse(fuseStateOptions, data), fuseResult = _l.fuseResult, doFuseSearch = _l.doFuseSearch, groupBy = _l.groupBy, resetFuse = _l.resetFuse;
    // two way binding
    React.useEffect(function () {
        if (!searchInput)
            return;
        setInputVal(searchInput);
    }, [searchInput, data]);
    // when value set from outside -> do a fuse serach once
    React.useEffect(function () {
        if (!searchInput)
            return;
        // when value set from outside -> trigger search once.
        if (searchOnClick && !fuseResult && data) {
            doFuseSearch(searchInput);
            if (onSearch)
                onSearch(searchInput);
        }
    }, [data]);
    // when input change do search when not in clickmode.
    // timer delays init auf fusesearch(e.g. if multiple inputs)
    React.useEffect(function () {
        if (fuseSearchInputDelay.current)
            clearTimeout(fuseSearchInputDelay.current);
        if (!searchOnClick && inputVal) {
            fuseSearchInputDelay.current = setTimeout(function () {
                if (fuseSearchInputDelay.current) {
                    doFuseSearch(inputVal);
                    if (onSearch)
                        onSearch(inputVal);
                }
            }, 300);
        }
        else if (inputVal === null) {
            resetFuse();
        }
    }, [searchInput, data, inputVal]);
    var handleInput = function (val) {
        setInputVal(val);
        // ensure two way binding
        if (onInput)
            onInput(val ? val : "");
    };
    var toggleFuseKey = function (fuseKeys) {
        var copy = JSON.parse(JSON.stringify(fuseSearchInputDelay));
        copy.keys = fuseKeys;
        setFuseStateOptions(copy);
    };
    /**
     * Trigger fuse search whenever fuse options change.
     */
    React.useEffect(function () {
        //do only fire 
        if (fuseOptions === fuseStateOptions)
            return;
        if (!inputVal)
            return;
        doFuseSearch(inputVal);
    }, [fuseStateOptions]);
    return (React.createElement(FuzzyInputProvider, { fuseStateOptions: fuseStateOptions, fuseKeyMap: fuseKeyMap, toggleFuseKey: toggleFuseKey, clickMode: searchOnClick, doSearch: doFuseSearch, onSearch: onSearch, handleInput: handleInput, inputVal: inputVal, placeHolder: placeHolder, data: data },
        React.createElement(FuzzyResultProvider, { fuzzyResult: fuseResult, onSelect: onSelect, resultCountLabel: resultCountLabel, showResultGrid: showResultGrid, tagConceptMap: tagConceptMap }, children ? children : React.createElement(FuzzyGui, { markOptions: markOptions }))));
};
export default ZIMFuzzySearch;
